@@ -96,8 +96,10 @@ TpChannelGroupChangeReason tp_channel_group_change_reason_from_folks_groups_chan
 TpfPersonaStore * empathy_dup_persona_store_for_connection (
     TpConnection *connection);
 gboolean empathy_connection_can_add_personas (TpConnection *connection);
-gboolean empathy_connection_can_alias_personas (TpConnection *connection);
-gboolean empathy_connection_can_group_personas (TpConnection *connection);
+gboolean empathy_connection_can_alias_personas (TpConnection *connection,
+						FolksIndividual *individual);
+gboolean empathy_connection_can_group_personas (TpConnection *connection,
+						FolksIndividual *individual);
 gboolean empathy_folks_persona_is_interesting (FolksPersona *persona);
 
 gchar * empathy_get_x509_certificate_hostname (gnutls_x509_crt_t cert);
@@ -108,6 +110,9 @@ gchar *empathy_format_currency (gint amount,
 
 gboolean empathy_account_has_uri_scheme_tel (TpAccount *account);
 
+TpContact * empathy_get_tp_contact_for_individual (FolksIndividual *individual,
+    TpConnection *conn);
+
 /* Copied from wocky/wocky-utils.h */
 
 #define empathy_implement_finish_void(source, tag) \
